@@ -145,7 +145,7 @@ module OpenID
         end
 
         def test_unexpected_arg_okay
-          assert_bad_args("Parameter foo does", {
+          assert_bad_args("Unexpected parameter", {
               'openid.mode' => 'id_res',
               'openid.return_to' => 'http://example.com/',
               'foo' => 'bar',
@@ -158,7 +158,7 @@ module OpenID
             'openid.return_to' => 'http://example.com/?foo=bar',
             })
 
-          assert_bad_args('Parameter foo val', {
+          assert_bad_args("Parameter 'foo' val", {
             'openid.mode' => 'id_res',
             'openid.return_to' => 'http://example.com/?foo=bar',
             'foo' => 'foos',
@@ -314,22 +314,6 @@ module OpenID
           }
         end
 
-        def test_kv_server_error
-          OpenID.extend(OverrideMethodMixin)
-          send_error = lambda do |req, server_url|
-            msg = Message.new(OPENID2_NS)
-            raise ServerError.from_message(msg), 'For you!'
-          end
-
-          OpenID.with_method_overridden(:make_kv_post, send_error) do
-            assert_protocol_error("Error from") {
-              call_check_auth do |idres|
-                idres.instance_def(:create_check_auth_request) { nil }
-              end
-            }
-          end
-        end
-
         def test_check_auth_okay
           OpenID.extend(OverrideMethodMixin)
           me = self
@@ -619,7 +603,9 @@ module OpenID
                                  'identity' => 'sour grapes',
                                  'claimed_id' => 'monkeysoft',
                                  'op_endpoint' => 'Phone Home'}) do |idres|
-              idres.instance_def(:discover_and_verify) {@endpoint = endpoint}
+              idres.instance_def(:discover_and_verify) do |to_match|
+                @endpoint = endpoint
+              end
             end
           }
           assert(endpoint.equal?(result))
@@ -640,7 +626,9 @@ module OpenID
                                  'claimed_id' => 'monkeysoft',
                                  'op_endpoint' => 'Green Cheese'}) do |idres|
                         idres.extend(InstanceDefExtension)
-              idres.instance_def(:discover_and_verify) {@endpoint = endpoint}
+              idres.instance_def(:discover_and_verify) do |to_match|
+                @endpoint = endpoint
+              end
             end
           }
           assert(endpoint.equal?(result))
@@ -721,7 +709,7 @@ module OpenID
             assert_raises(verified_error) {
               call_verify_modify({'ns' => OPENID1_NS,
                                    'identity' => @endpoint.local_id}) { |idres|
-                idres.instance_def(:discover_and_verify) do
+                idres.instance_def(:discover_and_verify) do |to_match|
                   raise verified_error
                 end
               }
